@@ -18,25 +18,56 @@ package Dist::Zilla::Plugin::ArchiveRelease;
 #---------------------------------------------------------------------
 
 use 5.008;
-our $VERSION = '0.03';
-# This file is part of Dist-Zilla-PluginBundle-CJM 0.03 (March 15, 2010)
+our $VERSION = '0.04';
+# This file is part of Dist-Zilla-PluginBundle-CJM 0.04 (March 29, 2010)
 
 
 use Moose;
 use Moose::Autobox;
+with 'Dist::Zilla::Role::BeforeRelease';
 with 'Dist::Zilla::Role::Releaser';
 
-use autodie ':io';
-use Path::Class qw(file);
+use Path::Class ();
 #---------------------------------------------------------------------
 
 
-has directory => (
+has _directory => (
   is       => 'ro',
   isa      => 'Str',
   default  => 'releases',
+  init_arg => 'directory',
 );
 
+sub directory
+{
+  my $self = shift;
+
+  Path::Class::dir($self->_directory)->absolute($self->zilla->root);
+} # end get_directory
+
+#---------------------------------------------------------------------
+sub before_release
+{
+  my ($self, $tgz) = @_;
+
+  my $dir = $self->directory;
+
+  # If the directory doesn't exist, create it:
+  unless (-d $dir) {
+    my $dirR = $dir->relative($self->zilla->root);
+
+    mkdir $dir or $self->log_fatal("Unable to create directory $dirR: $!");
+    $self->log("Created directory $dirR");
+  }
+
+  # If the tarball has already been archived, abort:
+  my $file = $dir->file($tgz->basename);
+
+  $self->log_fatal(["%s already exists",
+                    $file->relative($self->zilla->root)->stringify])
+      if -e $file;
+} # end before_release
+
 #---------------------------------------------------------------------
 # Main entry point:
 
@@ -46,11 +77,12 @@ sub release
 
   chmod(0444, $tgz);
 
-  my $dest = file($self->directory, $tgz->basename);
+  my $dest = $self->directory->file($tgz->basename);
+  my $destR = $dest->relative($self->zilla->root);
 
-  rename $tgz, $dest;
+  rename $tgz, $dest or $self->log_fatal("Failed to move to $destR: $!");
 
-  $self->log("Moved to $dest");
+  $self->log("Moved to $destR");
 } # end release
 
 #---------------------------------------------------------------------
@@ -66,9 +98,9 @@ Dist::Zilla::Plugin::ArchiveRelease - Move the release tarball to an archive dir
 
 =head1 VERSION
 
-This document describes version 0.03 of
-Dist::Zilla::Plugin::ArchiveRelease, released March 15, 2010
-as part of Dist-Zilla-PluginBundle-CJM version 0.03.
+This document describes version 0.04 of
+Dist::Zilla::Plugin::ArchiveRelease, released March 29, 2010
+as part of Dist-Zilla-PluginBundle-CJM version 0.04.
 
 =head1 DESCRIPTION
 
@@ -85,9 +117,12 @@ find the file being released).
 
 The directory to which the tarball will be moved.
 Defaults to F<releases>.
+If the directory doesn't exist, it will be created during the
+BeforeRelease phase.
 
 
 =for Pod::Coverage
+before_release
 release
 
 =head1 INCOMPATIBILITIES
